@@ -161,10 +161,10 @@ void CDasherViewSquare::RenderGroups(CDasherNode *Render, myint y1, myint y2, in
   CDasherNode::ChildMap & Children = Render->Children();
   if(Children.size() == 0)
     return;
-  int current = 0;
+  //int current = 0;
   std::string Label = "";
 
-  myint range = y2 - y1;
+  //myint range = y2 - y1;
 
   //  const CAlphabet & alphabet = DasherModel()->GetAlphabet();
 
@@ -568,10 +568,10 @@ void CDasherViewSquare::SetScaleFactor( void )
   dTBHScaleFactor = iScreenWidth / static_cast<double>( iMaxY - iMinY );
   dTBVScaleFactor = iScreenHeight / static_cast<double>( iMaxX - iMinX );
 
-  iLRScaleFactorX = std::max(std::min(dLRHScaleFactor, dLRVScaleFactor), dLRHScaleFactor / 4.0) * m_iScalingFactor;
-  iLRScaleFactorY = std::max(std::min(dLRHScaleFactor, dLRVScaleFactor), dLRVScaleFactor / 4.0) * m_iScalingFactor;
-  iTBScaleFactorX = std::max(std::min(dTBHScaleFactor, dTBVScaleFactor), dTBVScaleFactor / 4.0) * m_iScalingFactor;
-  iTBScaleFactorY = std::max(std::min(dTBHScaleFactor, dTBVScaleFactor), dTBHScaleFactor / 4.0) * m_iScalingFactor;
+  iLRScaleFactorX = myint(std::max(std::min(dLRHScaleFactor, dLRVScaleFactor), dLRHScaleFactor / 4.0) * m_iScalingFactor);
+  iLRScaleFactorY = myint(std::max(std::min(dLRHScaleFactor, dLRVScaleFactor), dLRVScaleFactor / 4.0) * m_iScalingFactor);
+  iTBScaleFactorX = myint(std::max(std::min(dTBHScaleFactor, dTBVScaleFactor), dTBVScaleFactor / 4.0) * m_iScalingFactor);
+  iTBScaleFactorY = myint(std::max(std::min(dTBHScaleFactor, dTBVScaleFactor), dTBHScaleFactor / 4.0) * m_iScalingFactor);
 }
 
 void CDasherViewSquare::GetScaleFactor( int eOrientation, myint *iScaleFactorX, myint *iScaleFactorY ) {
@@ -1229,11 +1229,6 @@ void CDasherViewSquare::GoTo(screenint mousex, screenint mousey) {
 
 void CDasherViewSquare::NewDrawGoTo(myint iDasherMin, myint iDasherMax, bool bActive) {
 
-  screenint left;
-  screenint top;
-  screenint right;
-  screenint bottom;
-
   myint iHeight(iDasherMax - iDasherMin);
 
   int iColour;
