@@ -1,3 +1,6 @@
+#include "Common/Common.h"
+#include "AppSettings.h"
+
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <glade/glade.h>
@@ -43,11 +46,6 @@ static const struct poptOption options[] = {
 };
 #endif
 
-#define PREFIX "/usr/"
-#define SYSCONFDIR "/usr/share/dasher/"
-#define LIBDIR "/usr/lib/"
-#define DATADIR "/usr/share/dasher/"
-
 #include <libintl.h>
 #include <locale.h>
 #include <stdio.h>
@@ -68,7 +66,7 @@ static const struct poptOption options[] = {
 #include "speech.h"
 #endif
 
-#include "accessibility.h"
+//#include "accessibility.h"
 
 //extern GConfClient *the_gconf_client;
 
@@ -86,7 +84,10 @@ extern int oldx, oldy;
 GdkFilterReturn dasher_discard_take_focus_filter(GdkXEvent *xevent, GdkEvent *event, gpointer data) {
   XEvent *xev = (XEvent *) xevent;
 
-  if(xev->xany.type == ClientMessage && (Atom) xev->xclient.data.l[0] == gdk_x11_atom_to_xatom(gdk_atom_intern("WM_TAKE_FOCUS", False)) && keyboardmodeon == true) {
+  //  if(xev->xany.type == ClientMessage && (Atom) xev->xclient.data.l[0] == gdk_x11_atom_to_xatom(gdk_atom_intern("WM_TAKE_FOCUS", False)) && keyboardmodeon == true) {
+
+if(xev->xany.type == ClientMessage && (Atom) xev->xclient.data.l[0] == gdk_x11_atom_to_xatom(gdk_atom_intern("WM_TAKE_FOCUS", False))) {
+
     return GDK_FILTER_REMOVE;
   }
   else {
@@ -101,10 +102,6 @@ int main(int argc, char *argv[]) {
   HildonAppView *appview;
 #endif
 
-  int c;
-  XWMHints wm_hints;
-  Atom wm_window_protocols[3];
-
   bindtextdomain(PACKAGE, LOCALEDIR);
   bind_textdomain_codeset(PACKAGE, "UTF-8");
   textdomain(PACKAGE);
@@ -175,7 +172,7 @@ int main(int argc, char *argv[]) {
   // FIXME - apparently there's a function gnome_gconf_get_client - maybe we should use this if building with gnome
   
   g_pGConfClient = gconf_client_get_default();
-  g_print("Client=%p\n",g_pGConfClient);
+  //  g_print("GConf Client=%p\n",g_pGConfClient);
 
   // ---
 
@@ -190,6 +187,11 @@ int main(int argc, char *argv[]) {
 
   //  g_type_class_ref(dasher_gtk_text_view_get_type());
 
+  g_set_application_name (_("Dasher"));
+#ifndef WITH_MAEMO
+  gtk_window_set_default_icon_name ("dasher");
+#endif
+
 #ifdef WITH_GPE
   xml = glade_xml_new(PROGDATA "/dashergpe.glade", NULL, NULL);
 #elif WITH_MAEMO
@@ -197,6 +199,9 @@ int main(int argc, char *argv[]) {
 #else
   xml = glade_xml_new(PROGDATA "/dasher.glade", NULL, NULL);
 #endif
+  if (!xml) {
+    g_error("Can't find dasher.glade. Probably not installed properly ...\n");
+  }
 
 #if (defined GNOME_SPEECH || defined GNOME_A11Y)
   if(!bonobo_init(&argc, argv)) {
@@ -225,12 +230,34 @@ int main(int argc, char *argv[]) {
 
   InitialiseMainWindow(argc, argv, xml);
 
+
+
 #ifdef WITH_GPE
   gtk_window_set_decorated(GTK_WINDOW(window), false);
 #endif
 
 #ifndef WITH_MAEMO
   gtk_widget_show(window);
+
+
+ if(get_app_parameter_bool(APP_BP_KEYBOARD_MODE)) {
+    XWMHints wm_hints;
+    Atom wm_window_protocols[3];
+    
+    wm_window_protocols[0] = gdk_x11_get_xatom_by_name("WM_DELETE_WINDOW");
+    wm_window_protocols[1] = gdk_x11_get_xatom_by_name("_NET_WM_PING");
+    wm_window_protocols[2] = gdk_x11_get_xatom_by_name("WM_TAKE_FOCUS");
+    
+    wm_hints.flags = InputHint;
+    wm_hints.input = False;
+    
+    XSetWMHints(GDK_WINDOW_XDISPLAY(window->window), GDK_WINDOW_XWINDOW(window->window), &wm_hints);
+    XSetWMProtocols(GDK_WINDOW_XDISPLAY(window->window), GDK_WINDOW_XWINDOW(window->window), wm_window_protocols, 3);
+    gdk_window_add_filter(window->window, dasher_discard_take_focus_filter, NULL);
+    gtk_window_set_keep_above(GTK_WINDOW(window), true);
+  } 
+
+
 #else
   appview = HILDON_APPVIEW( hildon_appview_new(NULL) );
   app = HILDON_APP( hildon_app_new() );
@@ -269,29 +296,16 @@ int main(int argc, char *argv[]) {
 #endif
 
   setup = TRUE;
-
-  wm_window_protocols[0] = gdk_x11_get_xatom_by_name("WM_DELETE_WINDOW");
-  wm_window_protocols[1] = gdk_x11_get_xatom_by_name("_NET_WM_PING");
-  wm_window_protocols[2] = gdk_x11_get_xatom_by_name("WM_TAKE_FOCUS");
-
-  wm_hints.flags = InputHint;
-  wm_hints.input = False;
-
-#ifndef WITH_MAEMO
-  XSetWMHints(GDK_WINDOW_XDISPLAY(window->window), GDK_WINDOW_XWINDOW(window->window), &wm_hints);
-  XSetWMProtocols(GDK_WINDOW_XDISPLAY(window->window), GDK_WINDOW_XWINDOW(window->window), wm_window_protocols, 3);
-  gdk_window_add_filter(window->window, dasher_discard_take_focus_filter, NULL);
+#ifdef PJC_EXPERIMENTAL
+  SetupWMHints();
 #endif
 
 #ifdef GNOME_SPEECH
   setup_speech();
 #endif
 
-  setupa11y();
-
-  // FIXME - REIMPLEMENT
-//   controltree=gettree();
-//   add_control_tree(controltree);
+  // A11y support disabled for now
+  //  setupa11y();
 
   if(optind < argc) {
     if(!g_path_is_absolute(argv[optind])) {
@@ -322,10 +336,11 @@ int main(int argc, char *argv[]) {
   gnome_vfs_shutdown();
 #endif
 
-#ifdef GNOME_A11Y
-  deletemenutree();
-  SPI_exit();
-#endif
+  // A11y sypport disabled for now
+  //#ifdef GNOME_A11Y
+  //  deletemenutree();
+  //  SPI_exit();
+  //#endif
 
   // Take down GConf client
 
